//
// VPNUAccountStatus.h
// VPNUnlimitedSDK
//
// Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CLLocation.h>
#import <VPNUnlimitedSDK/VPNUConstants.h>

/*!
 @class VPNUAccountStatus
 @abstract
 A model object which describes user's account status.
 */

NS_AVAILABLE(10_7, 7_0)
@interface VPNUAccountStatus : NSObject <NSCoding>
/*!
 @brief Array of strings describing user's preferred VPN protocols.
 */
@property (strong, readonly) NSArray *preferredProtocols NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Default protocol based on contents of `preferredProtocols` field.
 */
@property (assign, readonly) VPNUProtocol defaultProtocol NS_AVAILABLE(10_11, 9_0);
/*!
 @brief User's current VPN region.
 */
@property (copy, readonly) NSString *currentRegion NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A date on which the account was created.
 */
@property (strong, readonly) NSDate *creationDate NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A date of current account expiration.
 */
@property (strong, readonly) NSDate *expiredDate NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Number of seconds left till account expiration.
 */
@property (assign, readonly) long long secondsLeft NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A human-readable string which describes the time left till account expiration.
 */
@property (copy, readonly) NSString *timeLeftString NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Total traffic for account (in bytes).
 */
@property (assign, readonly) long long trafficUsed NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A boolean value which indicates if the account is expired.
 */
@property (assign, readonly, getter=isExpired) BOOL expired NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A boolean value which indicates if VPN connection is active.
 */
@property (assign, readonly, getter=isVpnActive) BOOL vpnActive NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Returns current IP address.
 */
@property (copy, readonly) NSString *serverIP NS_AVAILABLE(10_7, 7_0);
/*!
 @brief returns real IP address even if connected to VPN.
 */
@property (copy, readonly) NSString *realIP NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Country.
 */
@property (copy, readonly) NSString *country NS_AVAILABLE(10_7, 7_0);
/*!
 @brief City.
 */
@property (copy, readonly) NSString *city NS_AVAILABLE(10_7, 7_0);
/*!
 @brief URL of country's flag image.
 */
@property (copy, readonly) NSString *flagURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief URL of country's flat flag image.
 */
@property (copy, readonly) NSString *flatFlagURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief URL of country's flag bigger image.
 */
@property (copy, readonly) NSString *flagHDURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief User's name as it appears in system.
 */
@property (copy, readonly) NSString *vpnUsername NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Try personal server per as it appears in system.
 */
@property (assign, readonly) BOOL tryPersonalServer NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Try show 32-bit version per as it appears in system.
 */
@property (assign, readonly) BOOL show32bitVersion NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A structure that contains a user's geographical coordinate.
 */
@property (nonatomic, readonly, assign) CLLocationCoordinate2D coordinates NS_AVAILABLE(10_7, 7_0);

/*!
 @deprecated This field is deprecated. Use `preferredProtocols` instead.
 */
@property (strong, readonly) NSArray *preferedProtocols NS_AVAILABLE(10_7, 7_0) DEPRECATED_ATTRIBUTE;
/*!
 @deprecated This field is deprecated. Use `preferredProtocols` instead.
 */
@property (strong, readonly) NSArray *prefferedProtocol NS_AVAILABLE(10_7, 7_0) DEPRECATED_ATTRIBUTE;

@end
