//
//  VPNUAuthDelegateProtocol.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <Foundation/Foundation.h>

typedef void (^VPNUAuthDelegateCompletionHandler)(BOOL succesful, NSString *action, NSDictionary *authParams);

/*!
 @protocol VPNUAuthDelegateProtocol
 @abstract
 Protocol for implementing custom authorization.
 @discussion
 If you use custom authorization routines (like Facebook or Google Plus), you implement methods by this protocol to provide the results of this authorization. First you must return @c YES in @c willImplementCustomAuthorization method. Then, when @c resolveCustomAuthorizationWithHandler: is called, you finish the authorization routine and call the authorization completion handler with appropriate parameters.
 @code - (BOOL)willImplementCustomAuthorization {
 return _authType == authTypeSocial;
 }
 
 - (void)resolveCustomAuthorizationWithHandler:(VPNUAuthDelegateCompletionHandler)completionHandler {
 NSDictionary *authParams = @{@"login":login,
 @"oauthservice":@"facebook",
 @"oauthcredentials":oauthJsonString,
 @"deviceid":[[[ASIdentifierManager sharedManager] advertisingIdentifier] UUIDString]};
 
 completionHandler(YES, @"loginsocial", authParams);
}
 */
@protocol VPNUAuthDelegateProtocol <NSObject>
@required
- (BOOL)willImplementCustomAuthorization;
- (void)resolveCustomAuthorizationWithHandler:(VPNUAuthDelegateCompletionHandler)completionHandler;

@end
