//
//  VPNUPurchaseItem.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <Foundation/Foundation.h>

/*!
 @class VPNUPurchaseItem
 @abstract
 A model object which describes purchased item.
 */
NS_AVAILABLE(10_7, 7_0)
@interface VPNUPurchaseItem : NSObject

/*!
 @brief Receipt string.
 */
@property (nonatomic, copy) NSString *receipt NS_AVAILABLE(10_7, 7_0);
/*!
 @brief ID of the purchase.
 */
@property (nonatomic, copy) NSString *purchaseID NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Price locale of the purchase.
 */
@property (nonatomic, copy) NSString *priceLocale NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Code for the country of purchase.
 */
@property (nonatomic, copy) NSString *purchaseCountryCode NS_AVAILABLE(10_7, 7_0);

/*!
 @brief Initializes and returns a newly allocated purchase item object with the specified parameters.
 @param receipt Purchase receipt string.
 @param purchaseID Purchase ID string.
 @param priceLocale Price locale of the purchase.
 @return An initialized purchase item object or nil if the object couldn't be created.
 */
- (instancetype)initWithReceipt:(NSString *)receipt andPurchaseId:(NSString *)purchaseID andPriceLocale:(NSString *)priceLocale andPurchaseCountryCode:(NSString*)purchaseCountryCode NS_AVAILABLE(10_7, 7_0) NS_DESIGNATED_INITIALIZER;

@end
