//
//  VPNUPurchaseManager.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <Foundation/Foundation.h>

@class VPNUPurchaseItem;
@class VPNUTransport;

/*!
 @class VPNUPurchaseManager
 @abstract
 This class provides an interface for validating a purchase.
 @discussion
 Before using this class you must authorize or register with the help of @c VPNUAuthorizer class. You must pass the same @c VPNUTransport instance to its constructor as you have passed to @c VPNUAuthorizer instance constructor.
 */
NS_AVAILABLE(10_7, 7_0)
@interface VPNUPurchaseManager : NSObject

#pragma mark - Public Methods
/*!
 @brief Validates a provided purchase item on server.
 @discussion This method blocks a calling thread.
 @warning This method shouldn't be called from main thread.
 @param purchaseItem A purchase item for which to perform the validation.
 @return @c nil if validation succeeded, error object otherwise.
 @see VPNUPurchaseItem
 */
- (NSError *)validatePurchaseItem:(VPNUPurchaseItem *)purchaseItem NS_AVAILABLE(10_7, 7_0);

#pragma mark - Life Cycle
/*!
 @brief Initializes and returns a newly allocated purchase manager object with the specified transport object.
 @param transport The transport object for internal usage.
 @return An initialized purchase manager object or nil if the object couldn't be created.
 */
- (instancetype)initWithTransport:(VPNUTransport *)transport NS_AVAILABLE(10_7, 7_0) NS_DESIGNATED_INITIALIZER;

/*!
 @brief Creates and returns a newly allocated purchase manager object with the specified transport object.
 @discussion This method is a convenience constructor.
 @param transport The transport object for internal usage.
 @return An initialized purchase manager object or nil if the object couldn't be created.
 */
+ (instancetype)purchaseManagerWithTransport:(VPNUTransport *)transport NS_AVAILABLE(10_7, 7_0);

@end
